<!DOCTYPE html><html lang="en"><!-- Mirrored from html.kodesolution.com/2023/satnet-html/shop-product-details.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:15:39 GMT --><head>
<meta charset="utf-8">
<title>Satnet | Broadband HTML Template</title>
<!-- Stylesheets -->
<link href="css/animate.css" rel="stylesheet">
<link href="css/bootstrap.min.css" rel="stylesheet">
<link href="css/slick.css" rel="stylesheet">
<link href="css/slick-theme.css" rel="stylesheet">
<link href="css/select2.min.css" rel="stylesheet">
<link href="css/swipebox.min.css" rel="stylesheet">
<link href="css/swiper-bundle.min.css" rel="stylesheet">
<link href="css/style.css" rel="stylesheet">

<link rel="shortcut icon" href="images/favicon2.png" type="image/x-icon">
<link rel="icon" href="images/favicon2.png" type="image/x-icon">

<!-- Responsive -->
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0">
<!--[if lt IE 9]><script src="https://cdnjs.cloudflare.com/ajax/libs/html5shiv/3.7.3/html5shiv.js"></script><![endif]-->
<!--[if lt IE 9]><script src="js/respond.js"></script><![endif]-->
<link rel="stylesheet" href="css/custom_elements.css?wS9xFZ3S" id="custom-elements-css"><link rel="stylesheet" href="css/code_editor_styles.css?tBDk75DC" id="custom-css"><link rel="stylesheet" href="font-awesome/font-awesome.min.css?f6V30WIt" id="font-awesome"></head>

<body class="layout4">

<div class="page-wrapper">

	<!-- Preloader -->
	<div class="preloader"></div>

    <!-- Main Header-->
	<header class="main-header header-style-four inner-page-style">
		<!-- Header Top -->
		<div class="header-top">
			<div class="container">
				<div class="header-top-content">
					<div class="top-left">
						<!-- Info List -->
                        <ul class="info-list">
                            <li>
                                <i class="icon fa-solid fa-wifi"></i>
                                <span>Existing customer? View our exclusive offers for you</span>
                            </li>
                            <li>
                                <a href="#">log in</a>
                            </li>
                        </ul>
					</div>
					<ul class="social-links">
                        <li><span>Follow Us!</span></li>
                        <li><a href="#" title=""><i class="fab fa-facebook"></i></a></li>
                        <li><a href="#" title=""><i class="fab fa-google-plus-g"></i></a></li>
                        <li><a href="#" title=""><i class="fa fa-x"></i></a></li>
                    </ul>
				</div>
			</div>
		</div>
		<!-- Header Top -->

        <div class="header-lower">
            <!-- Main box -->
            <div class="main-box">
                <div class="logo-box">
                    <div class="logo d-none d-lg-block"><a href="index.html"><img src="images/logo-v3-white.png" alt="" title="Satnet"></a></div>
                    <div class="logo d-block d-lg-none"><a href="index.html"><img src="images/logo-v4-black.png" alt="" title="Satnet"></a></div>
                </div>

                <!--Nav Box-->
                <div class="nav-outer">    
                    <nav class="nav main-menu">
                        <ul class="navigation">
                            <li class="current dropdown"><a href="index.html">Home</a>
                                <ul>
                                    <li><a href="index.html">Home page 01</a></li>
                                    <li><a href="index-2.html">Home page 02</a></li>
                                    <li><a href="index-3.html">Home page 03</a></li>
                                    <li><a href="index-4.html">Home page 04</a></li>
                                    <li class="dropdown"><a href="#">Single Styles</a>
                                        <ul>
                                            <li><a href="index-1-single.html">Single Style One</a></li>
                                            <li><a href="index-2-single.html">Single Style Two</a></li>
                                            <li><a href="index-3-single.html">Single Style Two</a></li>
                                            <li><a href="index-4-single.html">Single Style Two</a></li>
                                        </ul>
                                    </li>
                                    <li class="dropdown"><a href="#">Dark Styles</a>
                                        <ul>
                                            <li><a href="index-1-dark.html">Darl Style One</a></li>
                                            <li><a href="index-2-dark.html">Darl Style Two</a></li>
                                            <li><a href="index-3-dark.html">Darl Style Two</a></li>
                                            <li><a href="index-4-dark.html">Darl Style Two</a></li>
                                        </ul>
                                    </li>
                                    <li class="dropdown"><a href="#">Header Styles</a>
                                        <ul>
                                            <li><a href="index.html">Header Style One</a></li>
                                            <li><a href="index-2.html">Header Style Two</a></li>
                                        </ul>
                                    </li>
                                    <li><a href="index-1-rtl.html">RTL Style One</a></li>
                                </ul>
                            </li>
                            <li class="dropdown"><a href="page-services.html">Services</a>
                                <ul>
                                    <li><a href="page-services.html">Services Grid</a></li>
                                    <li><a href="page-service-details.html">Service Details</a></li>
                                </ul>
                            </li>
							<li class="dropdown"><a href="page-about.html">Pages</a>
								<ul>
									<li><a href="page-about.html">About</a></li>
									<li><a href="page-movie.html">Movie</a></li>
									<li><a href="page-pricing.html">Pricing</a></li>
									<li class="dropdown"><a href="shop-products.html">Shop</a>
										<ul>
											<li><a href="shop-products.html">Products</a></li>
											<li><a href="shop-products-sidebar.html">Products Sidebar</a></li>
											<li><a href="shop-product-details.html">Product Details</a></li>
											<li><a href="shop-cart.html">Cart</a></li>
											<li><a href="shop-checkout.html">Checkout</a></li>
										</ul>
									</li>
									<li><a href="page-team.html">Team</a></li>
									<li><a href="page-testimonial.html">Testimonial</a></li>
									<li><a href="page-faq.html">FAQ</a></li>
									<li><a href="page-404.html">Page 404</a></li>
								</ul>
							</li>
							<li class="dropdown"><a href="news-grid.html">News</a>
								<ul>
									<li><a href="news-grid.html">News Grid</a></li>
									<li><a href="news-details.html">News Details</a></li>
								</ul>
							</li>
                            <li><a href="page-contact.html">Contact</a></li>
                        </ul>
                    </nav>
                    <!-- Main Menu End-->
                </div>

                <div class="outer-box">
                    <!-- Header Search -->
						<button class="search-btn">
                            <i class="flaticon-search"></i>
						</button>
						<button class="login-btn">
                            <i class="flaticon-user"></i>
						</button>
                    <a href="#" title="" class="header-btn">Get Connection</a>
                    <div class="mobile-nav-toggler"><span class="icon lnr-icon-bars"></span></div>
                    <!-- Mobile Nav toggler -->
                </div>
            </div>
        </div>
		
		<!-- Mobile Menu  -->
		<div class="mobile-menu">
			<div class="menu-backdrop"></div>
		
			<!--Here Menu Will Come Automatically Via Javascript / Same Menu as in Header-->
			<nav class="menu-box">
				<div class="upper-box">
					<div class="nav-logo"><a href="index.html"><img src="images/logo-v2-white.png" alt="" title=""></a></div>
					<div class="close-btn"><i class="icon fa fa-times"></i></div>
				</div>
		
				<ul class="navigation clearfix">
					<!--Keep This Empty / Menu will come through Javascript-->
				</ul>
				<ul class="contact-list-one">
					<li>
						<!-- Contact Info Box -->
						<div class="contact-info-box">
							<i class="icon lnr-icon-phone-handset"></i>
							<span class="title">Call Now</span>
							<a href="tel:+92880098670">+92 (8800) - 98670</a>
						</div>
					</li>
					<li>
						<!-- Contact Info Box -->
						<div class="contact-info-box">
							<span class="icon lnr-icon-envelope1"></span>
							<span class="title">Send Email</span>
							<a href="https://html.kodesolution.com/cdn-cgi/l/email-protection#5139343d2111323e3c21303f287f323e3c"><span class="__cf_email__" data-cfemail="49212c2539092a262439282730672a2624">[email&nbsp;protected]</span></a>
						</div>
					</li>
					<li>
						<!-- Contact Info Box -->
						<div class="contact-info-box">
							<span class="icon lnr-icon-clock"></span>
							<span class="title">Send Email</span>
							Mon - Sat 8:00 - 6:30, Sunday - CLOSED
						</div>
					</li>
				</ul>
		
		
				<ul class="social-links">
					<li><a href="#"><i class="fa fa-x"></i></a></li>
					<li><a href="#"><i class="fab fa-facebook-f"></i></a></li>
					<li><a href="#"><i class="fab fa-pinterest"></i></a></li>
					<li><a href="#"><i class="fab fa-instagram"></i></a></li>
				</ul>
			</nav>
		</div><!-- End Mobile Menu -->

		<!-- Header Search -->
		<div class="search-popup">
			<span class="search-back-drop"></span>
			<button class="close-search"><span class="fa fa-times"></span></button>
		
			<div class="search-inner">
				<form method="post" action="https://html.kodesolution.com/2023/satnet-html/index.html">
					<div class="form-group">
						<input type="search" name="search-field" value="" placeholder="Search..." required="">
						<button type="submit"><i class="fa fa-search"></i></button>
					</div>
				</form>
			</div>
		</div>
		<!-- End Header Search -->

		<!-- Sticky Header  -->
		<div class="sticky-header">
			<div class="auto-container">
				<div class="inner-container">
					<!--Logo-->
					<div class="logo">
						<a href="index.html" title=""><img src="images/logo-v2-white.png" alt="" title=""></a>
					</div>
		
					<!--Right Col-->
					<div class="nav-outer">
						<!-- Main Menu -->
						<nav class="main-menu">
							<div class="navbar-collapse show collapse clearfix">
								<ul class="navigation clearfix">
									<!--Keep This Empty / Menu will come through Javascript-->
								</ul>
							</div>
						</nav><!-- Main Menu End-->
		
						<!--Mobile Navigation Toggler-->
						<div class="mobile-nav-toggler"><span class="icon lnr-icon-bars"></span></div>
					</div>
				</div>
			</div>
		</div><!-- End Sticky Menu -->
	</header>
	<!--End Main Header -->

	<!-- Start main-content -->
	<section class="page-title" style="background-image: url(images/background/page-title.jpg);">
		<div class="auto-container">
			<div class="title-outer">
				<ul class="page-breadcrumb">
					<li><a href="index.html">Home</a></li>
					<li>Shop</li>
				</ul>
				<h1 class="title">Product Deatils</h1>
			</div>
		</div>
	</section>
	<!-- end main-content -->

	<!--Product Details Start-->
	<section class="product-details">
		<div class="container pb-70">
			<div class="row">
				<div class="col-lg-6 col-xl-6">
					<div class="bxslider">
						<div class="slider-content">
							<figure class="image-box"><a href="images/resource/products/product-details.jpg" class="lightbox-image" data-fancybox="gallery"><img src="images/resource/products/product-details.jpg" alt=""></a></figure>
							<div class="slider-pager">
								<ul class="thumb-box">
									<li> <a class="active" data-slide-index="0" href="#">
										<figure><img src="images/resource/products/product-details.jpg" alt=""></figure>
										</a> </li>
									<li> <a data-slide-index="1" href="#">
										<figure><img src="images/resource/products/product-details2.jpg" alt=""></figure>
										</a> </li>
									<li> <a data-slide-index="2" href="#">
										<figure><img src="images/resource/products/product-details3.jpg" alt=""></figure>
										</a> </li>
								</ul>
							</div>
						</div>
						<div class="slider-content">
							<figure class="image-box"><a href="images/resource/products/product-details2.jpg" class="lightbox-image" data-fancybox="gallery"><img src="images/resource/products/product-details2.jpg" alt=""></a></figure>
							<div class="slider-pager">
								<ul class="thumb-box">
									<li> <a class="active" data-slide-index="0" href="#">
										<figure><img src="images/resource/products/product-details.jpg" alt=""></figure>
										</a> </li>
									<li> <a data-slide-index="1" href="#">
										<figure><img src="images/resource/products/product-details2.jpg" alt=""></figure>
										</a> </li>
									<li> <a data-slide-index="2" href="#">
										<figure><img src="images/resource/products/product-details3.jpg" alt=""></figure>
										</a> </li>
								</ul>
							</div>
						</div>
						<div class="slider-content">
							<figure class="image-box"><a href="images/resource/products/product-details3.jpg" class="lightbox-image" data-fancybox="gallery"><img src="images/resource/products/product-details3.jpg" alt=""></a></figure>
							<div class="slider-pager">
								<ul class="thumb-box">
									<li> <a class="active" data-slide-index="0" href="#">
										<figure><img src="images/resource/products/product-details.jpg" alt=""></figure>
										</a> </li>
									<li> <a data-slide-index="1" href="#">
										<figure><img src="images/resource/products/product-details2.jpg" alt=""></figure>
										</a> </li>
									<li> <a data-slide-index="2" href="#">
										<figure><img src="images/resource/products/product-details3.jpg" alt=""></figure>
										</a> </li>
								</ul>
							</div>
						</div>
					</div>
				</div>
				<div class="col-lg-6 col-xl-6 product-info">
					<div class="product-details__top">
						<h3 class="product-details__title">PTCL router <span>$76.00</span> </h3>
					</div>
					<div class="product-details__reveiw">
						<i class="fa fa-star"></i>
						<i class="fa fa-star"></i>
						<i class="fa fa-star"></i>
						<i class="fa fa-star"></i>
						<i class="fa fa-star"></i>
						<span>2 Customer Reviews</span>
					</div>
					<div class="product-details__content">
						<p class="product-details__content-text1">Aliquam hendrerit a augue insuscipit. Etiam
							aliquam massa quis des mauris commodo venenatis ligula commodo leez sed blandit
							convallis dignissim onec vel pellentesque neque.</p>
						<p class="product-details__content-text2"><strong>REF.</strong> 4231/406 <br>
							Available in store</p>
					</div>

					<div class="product-details__quantity">
						<h3 class="product-details__quantity-title">Choose quantity</h3>
						<div class="quantity-box">
							<button type="button" class="sub"><i class="fa fa-minus"></i></button>
							<input type="number" id="1" value="1">
							<button type="button" class="add"><i class="fa fa-plus"></i></button>
						</div>
					</div>


					<div class="product-details__buttons">
						<div class="product-details__buttons-1">
							<a href="shop-cart.html" class="theme-btn btn-style-one"><span class="btn-title">Add to Cart</span></a>
						</div>
						<div class="product-details__buttons-2">
							<a href="shop-product-details.html" class="theme-btn btn-style-one"><span class="btn-title">Add to Wishlist</span></a>
						</div>
					</div>
					<div class="product-details__social">
						<div class="title mt-10">
							<h3>Share with friends</h3>
						</div>
						<div class="ml-30 blog-details__social-list">
							<a href="shop-product-details.html"><i class="fa fa-x"></i></a>
							<a href="shop-product-details.html"><i class="fab fa-facebook"></i></a>
							<a href="shop-product-details.html"><i class="fab fa-pinterest-p"></i></a>
							<a href="shop-product-details.html"><i class="fab fa-instagram"></i></a>
						</div>
					</div>
				</div>
			</div>
		</div>
	</section>
	<!--Product Details End-->

	<!--Product Description Start-->
	<section class="product-description">
		<div class="container pt-0 pb-90">
			<div class="product-discription">
				<div class="tabs-box">
					<div class="tab-btn-box text-center">
						<ul class="tab-btns tab-buttons clearfix">
							<li class="tab-btn active-btn" data-tab="#tab-1">Description</li>
							<li class="tab-btn" data-tab="#tab-2">Reviews</li>
						</ul>
					</div>
					<div class="tabs-content">
						<div class="tab active-tab" id="tab-1">
							<div class="text">
								<h3 class="product-description__title">Description</h3>
								<p class="product-description__text1">Lorem ipsum dolor sit amet, cibo mundi ea duo, vim exerci
									phaedrum. There are many variations of passages of Lorem Ipsum available, but the majority have
									alteration in some injected or words which don't look even slightly believable. If you are going to
									use a passage of Lorem Ipsum, you need to be sure there isn't anything embarrang hidden in the
									middle of text.
								</p>
								<div class="product-description__list">
									<ul class="list-unstyled">
										<li>
											<p><span class="fa fa-arrow-right"></span> Nam at elit nec neque suscipit gravida.</p>
										</li>
										<li>
											<p><span class="fa fa-arrow-right"></span> Aenean egestas orci eu maximus tincidunt.</p>
										</li>
										<li>
											<p><span class="fa fa-arrow-right"></span> Curabitur vel turpis id tellus cursus laoreet.
											</p>
										</li>
									</ul>
								</div>
								<p class="product-description__tex2">All the Lorem Ipsum generators on the Internet tend to repeat
									predefined chunks as necessary, making this the first true generator on the Internet. It uses a
									dictionary of over 200 Latin words, combined with a handful of model sentence structures, to
									generate Lorem Ipsum which looks reasonable.
								</p>
							</div>
						</div>
						<div class="tab" id="tab-2">
							<div class="customer-comment">
								<div class="row clearfix">
									<div class="col-lg-6 col-md-6 col-sm-12 comment-column">
										<div class="single-comment-box">
											<div class="inner-box">
												<figure class="comment-thumb"><img src="images/resource/testi-1.jpg" alt=""></figure>
												<div class="inner">
													<ul class="rating clearfix">
														<li><i class="fas fa-star"></i></li>
														<li><i class="fas fa-star"></i></li>
														<li><i class="fas fa-star"></i></li>
														<li><i class="fas fa-star"></i></li>
														<li><i class="fas fa-star"></i></li>
													</ul>
													<h5>Jon D. William, <span>10 Jan, 2023 . 4:00 pm</span></h5>
													<p>Aliquam hendrerit a augue insuscipit. Etiam aliquam massa quis des mauris commodo.</p>
												</div>
											</div>
										</div>
									</div>
									<div class="col-lg-6 col-md-6 col-sm-12 comment-column">
										<div class="single-comment-box">
											<div class="inner-box">
												<figure class="comment-thumb"><img src="images/resource/testi-2.jpg" alt=""></figure>
												<div class="inner">
													<ul class="rating clearfix">
														<li><i class="fas fa-star"></i></li>
														<li><i class="fas fa-star"></i></li>
														<li><i class="fas fa-star"></i></li>
														<li><i class="fas fa-star"></i></li>
														<li><i class="fas fa-star"></i></li>
													</ul>
													<h5>Aleesha Brown, <span>12 Feb, 2023 . 8:00 pm</span></h5>
													<p>Aliquam hendrerit a augue insuscipit. Etiam aliquam massa quis des mauris commodo.</p>
												</div>
											</div>
										</div>
									</div>
								</div>
							</div>
							<div class="comment-box">
								<h3>Add Your Comments</h3>
								<form id="contact_form" name="contact_form" class="" action="https://html.kodesolution.com/2023/satnet-html/includes/sendmail.php" method="post">
									<div class="mb-3">
										<textarea name="form_message" class="form-control required" rows="7" placeholder="Enter Message"></textarea>
									</div>
									<div class="row">
										<div class="col-sm-6">
											<div class="mb-3">
												<input name="form_name" class="form-control" type="text" placeholder="Enter Name">
											</div>
										</div>
										<div class="col-sm-6">
											<div class="mb-3">
												<input name="form_email" class="form-control required email" type="email" placeholder="Enter Email">
											</div>
										</div>
									</div>
									<div class="col-lg-12 col-md-12 col-sm-12 column">
										<div class="review-box clearfix">
											<p>Your Review</p>
											<ul class="rating clearfix">
												<li><i class="far fa-star"></i></li>
												<li><i class="far fa-star"></i></li>
												<li><i class="far fa-star"></i></li>
												<li><i class="far fa-star"></i></li>
												<li><i class="far fa-star"></i></li>
											</ul>
										</div>
									</div>
									<div class="col-lg-12 col-md-12 col-sm-12 column">
										<div class="form-group clearfix">
											<div class="custom-controls-stacked">
												<label class="custom-control material-checkbox">
													<input type="checkbox" class="material-control-input">
													<span class="material-control-indicator"></span>
													<span class="description">Save my name, email, and website in this browser for the next time I comment.</span>
												</label>
											</div>
										</div>
									</div>
									<div class="mb-3">
										<input name="form_botcheck" class="form-control" type="hidden" value="">
										<button type="submit" class="theme-btn btn-style-one" data-loading-text="Please wait..."><span class="btn-title">Submit Comment</span></button>
									</div>
								</form>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	</section>
	<!--Product Description End-->

	<section class="related-product">
		<div class="container pt-0 pb-90">
			<h3>Related Products</h3>
			<div class="row clearfix">
				<div class="col">
					<!--MixitUp Galery-->
					<div class="mixitup-gallery">
						<div class="filter-list row">
							<!--Product Block-->
							<div class="product-block all mix pantry fruit col-lg-3 col-md-6 col-sm-12">
								<div class="inner-box">
									<div class="image"><a href="shop-product-details.html"><img src="images/resource/products/1.jpg" alt=""></a></div>
									<div class="content">
										<h4><a href="shop-product-details.html">Headphone</a></h4>
										<span class="price">$32.00</span>
										<span class="rating"><i class="fa fa-star"></i><i class="fa fa-star"></i><i class="fa fa-star"></i><i class="fa fa-star"></i><i class="fa fa-star"></i></span>
									</div>
									<div class="icon-box">
										<a href="shop-product-details.html" class="ui-btn like-btn"><i class="fa fa-heart"></i></a>
										<a href="shop-cart.html" class="ui-btn add-to-cart"><i class="fa fa-shopping-cart"></i></a>
									</div>
								</div>
							</div>

							<!--Product Block-->
							<div class="product-block all mix dairy meat fruit col-lg-3 col-md-6 col-sm-12">
								<div class="inner-box">
									<div class="image"><a href="shop-product-details.html"><img src="images/resource/products/2.jpg" alt=""></a></div>
									<div class="content">
										<h4><a href="shop-product-details.html">Lagage</a></h4>
										<span class="price">$32.00</span>
										<span class="rating"><i class="fa fa-star"></i><i class="fa fa-star"></i><i class="fa fa-star"></i><i class="fa fa-star"></i><i class="fa fa-star"></i></span>
									</div>
									<div class="icon-box">
										<a href="shop-product-details.html" class="ui-btn like-btn"><i class="fa fa-heart"></i></a>
										<a href="shop-cart.html" class="ui-btn add-to-cart"><i class="fa fa-shopping-cart"></i></a>
									</div>
								</div>
							</div>

							<!--Product Block-->
							<div class="product-block all mix pantry fruit vagetables col-lg-3 col-md-6 col-sm-12">
								<div class="inner-box">
									<div class="image"><a href="shop-product-details.html"><img src="images/resource/products/3.jpg" alt=""></a></div>
									<div class="content">
										<h4><a href="shop-product-details.html">Watch</a></h4>
										<span class="price">$32.00</span>
										<span class="rating"><i class="fa fa-star"></i><i class="fa fa-star"></i><i class="fa fa-star"></i><i class="fa fa-star"></i><i class="fa fa-star"></i></span>
									</div>
									<div class="icon-box">
										<a href="shop-product-details.html" class="ui-btn like-btn"><i class="fa fa-heart"></i></a>
										<a href="shop-cart.html" class="ui-btn add-to-cart"><i class="fa fa-shopping-cart"></i></a>
									</div>
								</div>
							</div>

							<!--Product Block-->
							<div class="product-block all mix dairy pantry meat vagetables col-lg-3 col-md-6 col-sm-12">
								<div class="inner-box">
									<div class="image"><a href="shop-product-details.html"><img src="images/resource/products/8.jpg" alt=""></a></div>
									<div class="content">
										<h4><a href="shop-product-details.html">SD Card</a></h4>
										<span class="price">$32.00</span>
										<span class="rating"><i class="fa fa-star"></i><i class="fa fa-star"></i><i class="fa fa-star"></i><i class="fa fa-star"></i><i class="fa fa-star"></i></span>
									</div>
									<div class="icon-box">
										<a href="shop-product-details.html" class="ui-btn like-btn"><i class="fa fa-heart"></i></a>
										<a href="shop-cart.html" class="ui-btn add-to-cart"><i class="fa fa-shopping-cart"></i></a>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	</section>

    <!-- main footer four -->
    <section class="footer-v4">
        <div class="footer-top">
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-lg-4 text-column">
                        <h4 class="title">Sign up for our <br>newsletter</h4>
                    </div>
                    <div class="col-lg-8 contact-info">
                        <div class="inner-box">
                            <p>Stay up to update with our latest news and products.</p>
                            <form>
                                <input type="text" name="email" placeholder="Enter your email address...">
                                <button type="submit">Subscribe</button>
                            </form>
                        </div>
                    </div><!--contact-info-->
                </div>
            </div>
        </div>
        <div class="container py-0">
            <div class="widgets-sections">
                <div class="footer-title text-center wow fadeInUp">
                    <img src="images/logo-v2.png" alt="">
                    <p>Our award-winning, experts customer support <br>is available 7 days a week</p>
                </div>
                <div class="contact-widget row align-items-center justify-content-center">
                    <div class="inner-box col-lg-3 col-md-4 col-sm-6 wow fadeInLeft">
                        <figure class="image"><img src="images/resource/phone.png" alt=""></figure>
                        <h6 class="title">+88(9800) 6802</h6>
                    </div>
                    <div class="inner-box col-lg-3 col-md-4 col-sm-6 wow fadeInUp" data-wow-delay="200ms">
                        <figure class="image"><img src="images/resource/phone-2.png" alt=""></figure>
                        <h6 class="title">Town 24/ United State</h6>
                    </div>
                    <div class="inner-box col-lg-3 col-md-4 col-sm-6 wow fadeInRight" data-wow-delay="300ms">
                        <figure class="image"><img src="images/resource/phone-3.png" alt=""></figure>
                        <h6 class="title"><a href="https://html.kodesolution.com/cdn-cgi/l/email-protection" class="__cf_email__" data-cfemail="b2e7c1d7c0dcd3dfd7f2d6dddfd3dbdc9cd1dddf">[email&nbsp;protected]</a></h6>
                    </div>
                </div>
            </div>
        </div>
        <div class="footer-bottom">
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-md-4 copyright-text text-center text-lg-start">
                        <p>Copyright © reserved by . koresolution.</p>
                    </div>
                    <div class="col-md-4 social-column text-center">
                        <ul class="social-links">
                            <li><a href="#" title=""><i class="fab fa-facebook-square"></i></a></li>
                            <li><a href="#" title=""><i class="fab fa-google-plus-g"></i></a></li>
                            <li><a href="#" title=""><i class="fa fa-x"></i></a></li>
                        </ul>
                    </div>
                    <div class="col-md-4 links-column text-center text-lg-end">
                        <ul class="other-links">
                            <li><a href="#" title="">About</a></li>
                            <li><a href="#" title="">Terms</a></li>
                            <li><a href="#" title="">privacy policy</a></li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- End footer section -->

</div><!-- End Page Wrapper -->


<!-- Scroll To Top -->
<div class="scroll-to-top scroll-to-target" data-target="html"><span class="fa fa-angle-up"></span></div>


<script data-cfasync="false" src="../../cdn-cgi/scripts/5c5dd728/cloudflare-static/email-decode.min.js"></script><script src="js/jquery.js"></script>
<script src="js/popper.min.js"></script>
<script src="js/bootstrap.min.js"></script>
<script src="js/jquery.fancybox.js"></script>
<script src="js/jquery-ui.js"></script>
<script src="js/jquery.countdown.js"></script>
<script src="js/bxslider.js"></script>
<script src="js/mixitup.js"></script>
<script src="js/wow.js"></script>
<script src="js/appear.js"></script>
<script src="js/select2.min.js"></script>
<script src="js/script.js"></script>

<!-- form submit -->
<script src="js/jquery.validate.min.js"></script>
<script src="js/jquery.form.min.js"></script>
<script>
	(function($) {
		$("#contact_form").validate({
			submitHandler: function(form) {
				var form_btn = $(form).find('button[type="submit"]');
				var form_result_div = '#form-result';
				$(form_result_div).remove();
				form_btn.before('<div id="form-result" class="alert alert-success" role="alert" style="display: none;"></div>');
				var form_btn_old_msg = form_btn.html();
				form_btn.html(form_btn.prop('disabled', true).data("loading-text"));
				$(form).ajaxSubmit({
					dataType:  'json',
					success: function(data) {
						if( data.status == 'true' ) {
							$(form).find('.form-control').val('');
						}
						form_btn.prop('disabled', false).html(form_btn_old_msg);
						$(form_result_div).html(data.message).fadeIn('slow');
						setTimeout(function(){ $(form_result_div).fadeOut('slow') }, 6000);
					}
				});
			}
		});
	})(jQuery);
</script>



<script id="custom-js" src="js/code_editor_scripts.js?FyCtRvZ9"></script></body><!-- Mirrored from html.kodesolution.com/2023/satnet-html/shop-product-details.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:15:46 GMT --></html>